@@ -1,13 +1,12 @@
 package File::Serialize::Serializer;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Role for defining File::Serialize serializers
-$File::Serialize::Serializer::VERSION = '1.0.0';
+$File::Serialize::Serializer::VERSION = '1.0.1';
 
 use strict;
 use warnings;
 
-use List::Util qw/ reduce/;
-use List::MoreUtils qw/ any /;
+use List::MoreUtils qw/ any all /;
 use Module::Info;
 use Module::Runtime qw/ use_module /;
 
@@ -31,7 +30,7 @@ sub does_extension {
 }
 
 sub is_operative {
-    reduce { $a and Module::Info->new_from_module($b)->file  } 1, $_[0]->required_modules;
+    all { Module::Info->new_from_module($_) } $_[0]->required_modules;
 }
 
 sub groom_serialize_options {
@@ -81,7 +80,7 @@ File::Serialize::Serializer - Role for defining File::Serialize serializers
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
 
 =head1 SYNOPSIS
 
